@@ -16,6 +16,7 @@ OC.L10N.register(
     "Press ⌘-C to copy." : "Pro zkopírování stiskněte ⌘-C.",
     "Press Ctrl-C to copy." : "Pro zkopírování stiskněte Ctrl-C.",
     "Address book name" : "Název adresáře kontaktů",
+    "Only these special characters are allowed: -_.!?#|()" : "Jsou povoleny pouze tyto speciální znaky:  -_.!?#|()",
     "Address book could not be created." : "Adresář se nepodařilo vytvořit.",
     "The selected image is too big (max 1MB)" : "Zvolený obrázek je příliš velký (max 1MB)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Tento kontakt je poškozen a byl obnoven. Prosím zkontrolujete data a proveďte uložení aby byly změny trvalé.",
@@ -50,12 +51,14 @@ OC.L10N.register(
     "Sort by" : "Seřadit podle",
     "{addressbook} shared by {owner}" : "{addressbook} sdílí {owner}",
     "Contact not found." : "Kontakt nenalezen",
-    "You don't have permission to write to this addressbook." : "Nemáte oprávnění k úpravě tohoto adresáře.",
+    "You don't have permission to write to this addressbook." : "Nemáte oprávnění k zápisu do tohoto adresáře.",
     "Contact could not be created." : "Kontakt se nepodařilo vytvořit.",
     "No contacts in file. Only vCard files are allowed." : "Žádné kontakty v souboru. Pouze soubory vCard jsou povoleny.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Jsou podporovány pouze vCard verze 4.0 (RFC6350) nebo verze 3.0 (RFC2426).",
+    "Contact could not be moved." : "Kontakt nemohl být přesunut.",
     "Contact could not be saved." : "Kontakt nemohl být uložen.",
-    "Waiting for the server to be ready..." : "Čekání na odpověď serveru...",
+    "Waiting for the server to be ready…" : "Čekání na odpověď serveru...",
+    "Importing…" : "Importování...",
     "Display name" : "Zobrazované jméno",
     "Nickname" : "Přezdívka",
     "Detailed name" : "Jméno podrobně",
@@ -73,11 +76,14 @@ OC.L10N.register(
     "Instant messaging" : "Komunikátor",
     "Phone" : "Telefon",
     "Mobile" : "Mobil",
+    "Work mobile" : "Pracovní mobil",
     "Fax" : "Fax",
     "Fax home" : "Fax domů",
     "Fax work" : "Fax do práce",
     "Pager" : "Pager",
     "Voice" : "Hlas",
+    "Car" : "Auto",
+    "Work pager" : "Pracovní pager",
     "Social network" : "Sociální síť",
     "Relationship" : "Vztah",
     "Spouse" : "Manželka",
@@ -85,7 +91,7 @@ OC.L10N.register(
     "Mother" : "Matka",
     "Father" : "Otec",
     "Parent" : "Rodič",
-    "Brother" : "Brat",
+    "Brother" : "Bratr",
     "Sister" : "Sestra",
     "Relative" : "Příbuzný",
     "Friend" : "Přítel",
