@@ -16,14 +16,18 @@ OC.L10N.register(
     "Press ⌘-C to copy." : "⌘-Cを押してコピーします。",
     "Press Ctrl-C to copy." : "Ctrl-Cを押してコピーします。",
     "Address book name" : "アドレス帳名",
+    "Only these special characters are allowed: -_.!?#|()" : "これらの特殊文字のみ許可されます: -_.!?#|()",
+    "Address book could not be created." : "アドレス帳を作成できませんでした。",
     "The selected image is too big (max 1MB)" : "選択した画像容量が大きすぎます (最大1 MB)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "このカードは壊れていて、修正されました。 データを確認して、変更を確定するために保存を押してください。",
     "No contacts in here" : "連絡先がありません",
     "Name" : "名前",
     "Organization" : "所属",
     "Title" : "タイトル",
+    "Add field …" : "項目を追加",
     "Save changes" : "変更を保存",
     "Address book" : "連絡帳",
+    "Loading contacts …" : "連絡先を読み込み中...",
     "Import into" : "インポート",
     "Importing..." : "インポート中...",
     "Select your addressbook" : "あなたのアドレス帳を選択してください",
@@ -51,7 +55,8 @@ OC.L10N.register(
     "No contacts in file. Only vCard files are allowed." : "ファイルに連絡先がありません。vCardファイルのみ有効です",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "vCard のバージョンは、4.0 (RFC6350) または、3.0 (RFC2426) をサポートしています。",
     "Contact could not be saved." : "連絡先を保存できませんでした。",
-    "Waiting for the server to be ready..." : "サーバー状況確認中",
+    "Waiting for the server to be ready…" : "サーバー状況確認中",
+    "Importing…" : "読み込み中...",
     "Display name" : "表示名",
     "Nickname" : "ニックネーム",
     "Detailed name" : "詳細名",
@@ -69,6 +74,7 @@ OC.L10N.register(
     "Instant messaging" : "インスタントメッセージ",
     "Phone" : "電話番号",
     "Mobile" : "携帯",
+    "Work mobile" : "職場携帯",
     "Fax" : "FAX",
     "Fax home" : "自宅FAX",
     "Fax work" : "職場FAX",
@@ -82,6 +88,9 @@ OC.L10N.register(
     "Brother" : "兄弟",
     "Sister" : "姉妹",
     "Friend" : "友人",
+    "Colleague" : "同僚",
+    "Manager" : "マネージャー",
+    "Assistant" : "アシスタント",
     "Gender" : "性別",
     "Female" : "女性",
     "Male" : "男性",
