@@ -11,11 +11,15 @@ OC.L10N.register(
     "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
     "can edit" : "môže upravovať",
     "Close" : "Zatvoriť",
+    "Enabled" : "Povolené",
+    "Disabled" : "Zakázané",
     "Copied!" : "Skopírované!",
     "Not supported!" : "Nepodporované!",
     "Press ⌘-C to copy." : "Pre kopírovanie, stlačte ⌘-C.",
     "Press Ctrl-C to copy." : "Pre kopírovanie, stlačte Ctrl-C.",
     "Address book name" : "Názov adresára kontaktov",
+    "Only these special characters are allowed: -_.!?#|()" : "Povolené sú len tieto špeciálne znaky: -_.!?#|()",
+    "Address book could not be created." : "Adresár sa nepodarilo sa vytvoriť",
     "The selected image is too big (max 1MB)" : "Vybraný obrázok je príliš veľký (max 1MB)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Poškodená karta bola opravená. Skontrolujte prosím údaje a stlačte uložiť pre uplatnenie zmien. ",
     "No contacts in here" : "Nie sú tu žiadne kontakty",
@@ -49,12 +53,14 @@ OC.L10N.register(
     "Sort by" : "Zoradiť podľa",
     "{addressbook} shared by {owner}" : "{addressbook} sprístupňuje {owner}",
     "Contact not found." : "Kontakt sa nenašiel",
-    "You don't have permission to write to this addressbook." : "Nemáte oprávnenie na zapisovanie do tohto adresára",
+    "You don't have permission to write to this addressbook." : "Pre zápis do tohto adresára nemáte oprávnenia.",
     "Contact could not be created." : "Kontakt nieje možné vytvoriť",
     "No contacts in file. Only vCard files are allowed." : "V súbore nie sú žiadne kontakty. Podporované sú len súbory vCard.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Podporované sú iba formáty vCard verzie 4.0 (RFC6350) alebo verzie 3.0 (RFC2426).",
+    "Contact could not be moved." : "Kontakt sa nedá presunúť",
     "Contact could not be saved." : "Kontakt nie je možné uložiť",
-    "Waiting for the server to be ready..." : "Čaká sa než bude pripravený server...",
+    "Waiting for the server to be ready…" : "Čaká sa než bude pripravený server...",
+    "Importing…" : "Importuje sa...",
     "Display name" : "Zobrazované meno",
     "Nickname" : "Prezývka",
     "Detailed name" : "Podrobné meno",
@@ -72,11 +78,14 @@ OC.L10N.register(
     "Instant messaging" : "Instant messaging",
     "Phone" : "Telefón",
     "Mobile" : "Mobil",
+    "Work mobile" : "Pracovný mobil",
     "Fax" : "Fax",
     "Fax home" : "Fax doma",
     "Fax work" : "Fax v práci",
     "Pager" : "Pager",
     "Voice" : "Odkazová schránka",
+    "Car" : "Auto",
+    "Work pager" : "Pracovný pager",
     "Social network" : "Sociálna sieť",
     "Relationship" : "Vzťah",
     "Spouse" : "Partner/ka",
