@@ -11,6 +11,8 @@ OC.L10N.register(
     "Share with users or groups" : "Dela med användare eller grupper",
     "can edit" : "kan redigera",
     "Close" : "Stäng",
+    "Enabled" : "Aktiverad",
+    "Disabled" : "Inaktiverad",
     "Copied!" : "Kopierat!",
     "Not supported!" : "Stöds inte!",
     "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
@@ -49,14 +51,17 @@ OC.L10N.register(
     "New contact" : "Ny kontakt",
     "Not grouped" : "Inte grupperad",
     "Sort by" : "Sortera efter",
+    "There is no address book available to create a contact." : "Det finns ingen adressbok tillgänglig för att skapa en kontakt.",
     "{addressbook} shared by {owner}" : "{addressbook} delad av {owner}",
     "Contact not found." : "Kontakt inte funnen.",
-    "You don't have permission to write to this addressbook." : "Du har inte behörighet att skriva i denna adressbok.",
+    "You don't have permission to write to this addressbook." : "Du har inte tillgång att skriva till denna adressbok.",
     "Contact could not be created." : "Kontakt kunde inte skapas",
     "No contacts in file. Only vCard files are allowed." : "Inga kontakter i fil. Bara vCard-filer är tillåtna.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Bara vCard version 4.0 (RFC6350) eller version 3.0 (RFC2426) stöds.",
+    "Contact could not be moved." : "Kontakt kunde inte flyttas.",
     "Contact could not be saved." : "Kontakt kunde inte sparas.",
-    "Waiting for the server to be ready..." : "Väntar på server att bli redo...",
+    "Waiting for the server to be ready…" : "Väntar på att servern ska bli klar...",
+    "Importing…" : "Importerar...",
     "Display name" : "Visningsnamn",
     "Nickname" : "Smeknamn",
     "Detailed name" : "Detaljerat namn",
@@ -74,11 +79,14 @@ OC.L10N.register(
     "Instant messaging" : "Snabbmeddelanden",
     "Phone" : "Telefon",
     "Mobile" : "Mobil",
+    "Work mobile" : "Mobil arbete",
     "Fax" : "Fax",
     "Fax home" : "Fax hem",
     "Fax work" : "Fax arbete",
     "Pager" : "Personsökare",
     "Voice" : "Röst",
+    "Car" : "Bil",
+    "Work pager" : "Personsökare Arbete",
     "Social network" : "Socialt nätverk",
     "Relationship" : "Relation",
     "Spouse" : "Make/Maka",
