@@ -11,11 +11,15 @@ OC.L10N.register(
     "Share with users or groups" : "和用户或者组群分享",
     "can edit" : "允许编辑",
     "Close" : "关闭",
+    "Enabled" : "已开启",
+    "Disabled" : "已禁用",
     "Copied!" : "已复制！",
     "Not supported!" : "不支持！",
     "Press ⌘-C to copy." : "按 ⌘-C 复制",
     "Press Ctrl-C to copy." : "按 Ctrl-C 复制",
     "Address book name" : "地址簿名称",
+    "Only these special characters are allowed: -_.!?#|()" : "只允许使用这些特殊字符：- _ . ! ? # | ( )",
+    "Address book could not be created." : "无法创建地址簿。",
     "The selected image is too big (max 1MB)" : "所选图片过大(最大1MB)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "此卡已损坏，已被修复。请检查数据并保存以使更改永久有效。",
     "No contacts in here" : "没有联系人",
@@ -29,6 +33,7 @@ OC.L10N.register(
     "Import into" : "导入到",
     "Importing..." : "正在导入...",
     "Select your addressbook" : "选择您的地址簿",
+    "Import is disabled because no writable address book had been found." : "因为没有找到可写入的地址簿，导入被禁用。",
     "No search result for {query}" : "未找到结果{query}",
     "All contacts" : "全部联系人",
     "Post office box" : "邮政信箱",
@@ -47,14 +52,17 @@ OC.L10N.register(
     "New contact" : "新建联系人",
     "Not grouped" : "未分组",
     "Sort by" : "排序方式",
+    "There is no address book available to create a contact." : "没有地址簿可用于创建联系人。",
     "{addressbook} shared by {owner}" : "由 {owner} 共享给您的 {addressbook}",
     "Contact not found." : "无法找到联系人.",
-    "You don't have permission to write to this addressbook." : "你无权编写此地址簿。",
+    "You don't have permission to write to this addressbook." : "你没有此地址簿的编写权限。",
     "Contact could not be created." : "无法创建联系人。",
     "No contacts in file. Only vCard files are allowed." : "没有发现联系人信息. 只允许 VCard 格式文件.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "仅支持 VCard v4.0版本 (RFC6350) 或 v3.0版本 (RFC2426).",
+    "Contact could not be moved." : "无法移动联系人。",
     "Contact could not be saved." : "联系人无法保存.",
-    "Waiting for the server to be ready..." : "等待服务器就绪...",
+    "Waiting for the server to be ready…" : "等待服务器就绪......",
+    "Importing…" : "导入中......",
     "Display name" : "显示名称",
     "Nickname" : "昵称",
     "Detailed name" : "全名",
@@ -72,11 +80,13 @@ OC.L10N.register(
     "Instant messaging" : "即时通讯",
     "Phone" : "电话",
     "Mobile" : "手机",
+    "Work mobile" : "工作电话",
     "Fax" : "传真",
     "Fax home" : "家庭传真",
     "Fax work" : "工作传真",
     "Pager" : "传呼机",
     "Voice" : "语音",
+    "Car" : "车",
     "Social network" : "社交网络",
     "Relationship" : "关系",
     "Spouse" : "配偶",
